@@ -1,5 +1,5 @@
 context("glicko2_run")
-data  <- data.frame( id = 1,name = c( "A", "B", "C", "D" ), rank  = c( 3, 4, 1, 2 ), weight=1.01, date=c("a","b","c","d"))
+data  <- data.frame( id = 1,name = c( "A", "B", "C", "D" ), rank  = c( 3, 4, 1, 2 ), weight=1.05, date=c("a","b","c","d"))
 sigma <- setNames( rep(1,4), c("A","B","C","D"))
 rd    <- setNames( rep(350,4), c("A","B","C","D") )
 
@@ -32,11 +32,20 @@ test_that("higher rating change for higher deviation",{
   ))
 })
 
-test_that("higher rating change for higher weight",{
+test_that("R and RD exacltly proportional to weight",{
+  r  <- c( 1500, 1400, 1550, 1700 ) 
+  rd <- c( 200,  30,   100,  300 )
+  model1 <- glicko2_run( rank | id ~ name, data = data, r = r ,rd = rd, weight="weight" )
+  model2 <- glicko2_run( rank | id ~ name, data = data, r = r ,rd = rd )
+  
   expect_true( all(
-    abs( 1500 - glicko2_run(formula = rank|id~name, data=data, weight="weight")$final_r ) >
-    abs( 1500 - glicko2_run(formula = rank|id~name, data=data)$final_r )
+    round((r - model1$final_r)/(r-model2$final_r),10)==1.05
   ))
+  
+  expect_true( all(
+    round((rd - model1$final_rd)/(rd-model2$final_rd),10)==1.05
+  ))
+  
 })
 
 test_that("higher deviation for higher sigma",{
